<?php
namespace App\Service;

use Exception;

/**
 * This MailService class for manage globally -
 * mail service in application.
 *---------------------------------------------------------------- */
class CoinBaseService
{
    const COINBASE_CHARGE_URL = 'https://api.commerce.coinbase.com/charges';
    const CURRENCY = 'USD';
    /**
     * @var configData - configData
     */
    protected $configData;

    /**
     * @var configItem - configItem
     */
    protected $configItem;

    protected $db;

    /**
     * Constructor.
     *
     *-----------------------------------------------------------------------*/
    public function __construct(
        $db
    ) {
        $this->configData = configItem();
        $this->db = $db;
    }


    /**
     * @param $request
     * @return array
     */
    public function processCoinBaseRequest($request)
    {
        $configItem = [];

        if (isset($this->configData)) {
            $configItem = $this->configData['payments']['gateway_configuration']['coinbase'];
        }

        try {
            $currentUser   = $this->getUserFromEmail($request['payer_email']);
            $paymentAmount = $request['amounts'][self::CURRENCY];
            $apiKey        = $configItem['apikey'] ?? '';
            $apiVersion    = $configItem['apiversion'] ?? '';
            $requestCharge = [
                'name'         => 'Point Purchase request from ' . $request['payer_email'],
                'description'  => 'Point Purchase',
                'local_price'  => ['amount' => $paymentAmount, 'currency' => self::CURRENCY],
                'pricing_type' => 'fixed_price',
                'metadata'     => [
                    'customer_id'   => $currentUser['iuid'],
                    'customer_name' => $currentUser['i_user_fullname']
                ]
            ];
            $createCharge = $this->createCharge($requestCharge, $apiKey, $apiVersion);
            if (!empty($createCharge['data'])) {
                $chargeId  = $createCharge['data']['code'] ?? '';
                $chargeUrl = $createCharge['data']['hosted_url'] ?? '';
                $userId    = $currentUser['iuid'];
                $point     = $this->getPointBaseOnPlanID($request['creditPlan'])['plan_amount'];
                $status    = end($createCharge['data']['timeline'])['status'];
                $orderKey  = $request['ORDS62f51c11bec95'];
                $insertCoinBaseRecord = $this->updateCoinBaseChargeRecord($userId, $orderKey, $chargeId, $chargeUrl, $point, $status);
                if($insertCoinBaseRecord){
                    return [
                        "point" => $point,
                        "charge_url" => $chargeUrl
                    ];
                }
            }
            return [];

        } catch (Exception $e) {
            //if payment failed set failed message
            $errorMessage['message'] = 'failed';

            //set error message if payment failed
            $errorMessage['errorMessage'] = $e->getMessage();

            //return error message array
            return (array) $errorMessage;
        }
    }

    public function createCharge($request, $apiKey, $apiVersion)
    {
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, self::COINBASE_CHARGE_URL);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_POST, 1);
        curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($request));
        $headers = array();
        $headers[] = 'Content-Type: application/json';
        $headers[] = 'X-Cc-Api-Key: '.$apiKey;
        $headers[] = 'X-Cc-Version: '.$apiVersion;
        curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
        $result = curl_exec($ch);
        if (curl_errno($ch)) {
            echo 'Error:' . curl_error($ch);
        }
        curl_close($ch);
        return json_decode($result, true );
    }

    /**
     * Update coinbase charge record
     * @param $userId
     * @param $orderKey
     * @param $chargeId
     * @param $chargeUrl
     * @param $point
     * @param $status
     * @return bool|void
     */
    public function updateCoinBaseChargeRecord($userId, $orderKey, $chargeId, $chargeUrl, $point, $status)
    {
        $query = "INSERT INTO `i_coinbase_charge` (`user_id`, `order_key`, `charge_id`, `charge_url`, `point`, `status`) VALUES ('" . $userId . "', '" . $orderKey . "', '" . $chargeId . "', '" . $chargeUrl . "', '" . $point . "', '" . $status . "');";
        $insertCoinBaseRecord = mysqli_query($this->db, $query) or die(mysqli_error($this->db));
        return true;
    }

    /**
     * @param $email
     * @return array|false|void|null
     */
    public function getUserFromEmail($email)
    {
        $query = "SELECT * FROM `i_users` WHERE `i_user_email` = '".$email."'";
        $getAccountDetails =  mysqli_query($this->db, $query) or die(mysqli_error($this->db));
        return mysqli_fetch_array($getAccountDetails, MYSQLI_ASSOC);
    }

    /**
     * Get point base on plantID
     * @param $plandId
     * @return array|false|void|null
     */
    public function getPointBaseOnPlanID($plandId)
    {
        $query = "SELECT * FROM `i_premium_plans` WHERE `plan_status` = '1' AND `plan_id` = '" . $plandId . "'";
        $pointData = mysqli_query($this->db, $query) or die(mysqli_error($this->db));
        return mysqli_fetch_array($pointData, MYSQLI_ASSOC);
    }

}