<?php
include_once __DIR__ . '/../includes/connect.php';
include_once  __DIR__ . '/../includes/mail/vendor/autoload.php';
require_once  __DIR__ . '/../includes/payment/methods/vendor/autoload.php';
use PHPMailer\PHPMailer\PHPMailer;
use PHPMailer\PHPMailer\Exception;

if(empty($LANG)) {
    include_once __DIR__ . '/../includes/inc.php';
    $iN = new iN_UPDATES($db);
    $inc = $iN->iN_Configurations();
    $defaultLanguage = $inc['default_language'];
    include_once  __DIR__ . '/../langs/'.$defaultLanguage.'.php';
}


updateVCB($LANG, $base_url, $db);

function updateVCB($lang, $base_url, $db) {
    try {
        $paymentData = getPaymentData($db);
        $vcbStatus = $paymentData['vcb_status'] ?? 0;
        if($vcbStatus) {
            $vcbAccountNumber = $paymentData['vcb_account_number'];
            $vcbAccountPassword = $paymentData['vcb_account_password'];
            $vcbAccountToken = $paymentData['vcb_account_token'];
            $tranferHistory = getTranferHistory($vcbAccountNumber, $vcbAccountPassword, $vcbAccountToken, $db);
            if ($tranferHistory['status'] === true) {
                $pendingTransactions = getAllPendingTransactions($db);
                if (
                    is_array($tranferHistory['transactions'])
                    && count($tranferHistory['transactions']) > 0
                    && is_array($pendingTransactions)
                    && count($pendingTransactions) > 0
                ) {
                    foreach ($pendingTransactions as $transaction) {
                        $orderKey = $transaction['order_key'];
                        foreach ($tranferHistory['transactions'] as $tranfer) {
                            if (strpos($tranfer['description'], $orderKey) !== false) {
                                $exchangeAmount = getExchangeAmount($orderKey, $db);
                                $transactionAmount = (float)$exchangeAmount['amount'];
                                if ($transactionAmount <= (float)$tranfer['amount']) {
                                    $order = getOrder($orderKey, $db);
                                    updatePaymentStatus($transaction['order_key'], $db);
                                    addCustomerPoint($transaction['payer_iuid_fk'],$transaction['plan_amount'],$db);
                                    sendEmail($order['amount'], $order['plan_amount'], $order['i_user_email'] ,$lang, $base_url, $db);
                                }
                                break;
                            }
                        }
                    }
                }
            }
        }
    }catch (\Exception $exception) {
        logger('[ERROR]updateVCB',$exception->getMessage(), $db);
    }
    return true;
}

function logger($type, $data, $db) {
    $query = "INSERT INTO `i_payment_log` (`type`, `data`, `timestamp`) VALUES ('".$type."', '".$data."', '".date("Y-m-d H:i:s")."')";
    $log = $db->prepare($query);
    if (!$log) {
        die($db->error);
    }
    $log->execute();
    return true;
}

/**
 * @param $planPoint
 * @param $planMoney
 * @param $customerEmail
 * @param $LANG
 * @param $base_url
 * @param $db
 * @return bool|void
 * @throws Exception
 */
function sendEmail($planPoint, $planMoney, $customerEmail, $LANG, $base_url, $db) {
    try {
        $iN = new iN_UPDATES($db);
        $inc = $iN->iN_Configurations();

        $smtpOrMail      = $inc['smtp_or_mail'];
        $smtpHost        = $inc['smtp_host'];
        $smtpUserName    = $inc['smtp_username'];
        $smtpEmail       = $inc['default_mail'] ?? NULL;
        $smtpPassword    = $inc['smtp_password'];
        $smtpEncryption  = $inc['smtp_encryption'];
        $smtpPort        = $inc['smtp_port'];
        $senderEmail     = $inc['sender_email'];
        $senderName      = $inc['sender_name'];
        $logo            = $inc['site_logo'] ?? NULL;
        $favicon         = $inc['site_favicon'] ?? '1';
        $siteLogoUrl     = $base_url . $logo;
        $siteFavicon     = $base_url . $favicon;
        $siteName        = $inc['site'];
        $businessAddress = $inc['business_address'];

        $mail = new PHPMailer(true);
        if ($smtpOrMail == 'mail') {
            $mail->IsMail();
        } else if ($smtpOrMail == 'smtp') {
            $mail->isSMTP();
            $mail->Host = $smtpHost; // Specify main and backup SMTP servers
            $mail->SMTPAuth = true;
            $mail->SMTPKeepAlive = true;
            $mail->Username = $smtpUserName; // SMTP username
            $mail->Password = $smtpPassword; // SMTP password
            $mail->SMTPSecure = $smtpPort; // Enable TLS encryption, `ssl` also accepted
            $mail->Port = 587;
            $mail->SMTPOptions = array(
                'ssl' => array(
                    'verify_peer' => false,
                    'verify_peer_name' => false,
                    'allow_self_signed' => true,
                ),
            );
        } else {
            return false;
        }
        $pointPurchasesuccess = $LANG['bought_point_success'];
        $pointPurchaseDetails = $iN->iN_TextReaplacement($LANG['thank_you_for_purchase_not'], [$planMoney, $planPoint]);
        $startUsingYourPoints = $LANG['start_using_your_points'];
        $notQualifyDocument = $LANG['not_qualify_document'];
        $instagramIcon = $iN->iN_SelectedMenuIcon('88');
        $facebookIcon = $iN->iN_SelectedMenuIcon('90');
        $twitterIcon = $iN->iN_SelectedMenuIcon('34');
        $linkedinIcon = $iN->iN_SelectedMenuIcon('89');
        include_once  __DIR__ . "/../includes/mailTemplates/pointPurchaseMailTemplate.php";
        $body = $bodyPointPurchased;
        $mail->setFrom($senderEmail, $senderName);
        $mail->IsHTML(true);
        $mail->addAddress($customerEmail); // Add a recipient
        $mail->Subject = preg_replace( '/{.*?}/', $planPoint, 'You bought {planPoint} points.');
        $mail->CharSet = 'utf-8';
        $mail->MsgHTML($body);
        if ($mail->send()) {
            $mail->ClearAddresses();
            return true;
        }
        return false;
    }catch (\Exception $e) {
        return false;
    }
}

/**
 * @param $orderKey
 * @param $db
 * @return array|false|void|null
 */
function getOrder($orderKey, $db)
{
    $query = "SELECT iup.*, ipp.amount, ipp.plan_amount, iu.i_user_email
            FROM `i_user_payments` as iup
            left join i_premium_plans as ipp 
            on ipp.plan_id=iup.credit_plan_id
            left join i_users as iu
            on iup.payer_iuid_fk = iu.iuid
            WHERE `order_key` = '" . $orderKey . "'";
    $order = mysqli_query($db, $query) or die(mysqli_error($db));
    $result = mysqli_fetch_array($order, MYSQLI_ASSOC);
    return $result;
}

function getExchangeAmount($orderKey, $db) {
    $query = "SELECT * FROM `i_vcb_transactions` WHERE `order_key` = '" . $orderKey . "'";
    $order = mysqli_query($db, $query) or die(mysqli_error($db));
    $result = mysqli_fetch_array($order, MYSQLI_ASSOC);
    return $result;
}

/**
 * Update payment status to success after add point base on order key
 * @param $orderKey
 * @param $db
 * @return bool|void
 */
function updatePaymentStatus($orderKey, $db)
{
    $query = "UPDATE `i_user_payments` SET `payment_status` = 'ok' WHERE `order_key` = '".$orderKey."'";
    $updateCharge = mysqli_query($db, $query) or die(mysqli_error($db));
    return true;
}

/**
 * @param $id
 * @param $point
 * @param $db
 * @return bool|void
 */
function addCustomerPoint($id, $point, $db)
{
    $customerPoint = (float)getCurrentCustomerPoint($id, $db);
    $pointAfter = (float)($customerPoint + $point);
    $query = "UPDATE `i_users` SET `wallet_points` = '".$pointAfter."' WHERE `iuid` = '".$id."';";
    $updatePoint = mysqli_query($db, $query) or die(mysqli_error($db));
    return true;
}

/**
 * @param $id
 * @param $db
 * @return int|mixed|void
 */
function getCurrentCustomerPoint($id, $db)
{
    $query = "SELECT `wallet_points` FROM `i_users` WHERE `iuid` = '".$id."'";
    $customerPoint = mysqli_query($db, $query) or die(mysqli_error($db));
    $result = mysqli_fetch_array($customerPoint, MYSQLI_ASSOC)['wallet_points'] ?? 0;
    return $result;
}

/**
 * @param $vcbAccountNumber
 * @param $vcbAccountPassword
 * @param $vcbAccountToken
 * @param $db
 * @return mixed
 */
function getTranferHistory($vcbAccountNumber, $vcbAccountPassword, $vcbAccountToken, $db)
{
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL,'https://api.web2m.com/historyapivcbv3/'.$vcbAccountPassword.'/'.$vcbAccountNumber.'/'.$vcbAccountToken);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    $result = curl_exec($ch);
    if (curl_errno($ch)) {
        echo 'Error:' . curl_error($ch);
        $loggerData = json_encode([
            'url' => 'https://api.web2m.com/historyapivcbv3/'.$vcbAccountPassword.'/'.$vcbAccountNumber.'/'.$vcbAccountToken,
            'vcb_account_number' => $vcbAccountNumber,
            'vcb_account_password' => $vcbAccountPassword,
            'vcb_account_token' => $vcbAccountToken,
            'response' => $result,
            'error' => curl_error($ch)
        ]);
        logger('[ERROR]VCBGetTranferHistory', $loggerData, $db);
    }
    curl_close($ch);
    return json_decode($result, true);
}

/**
 * @return false|float
 */
function getExchangeRate()
{
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, 'https://portal.vietcombank.com.vn/Usercontrols/TVPortal.TyGia/pXML.aspx?b=1');
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'GET');

    $headers = array();
    $headers[] = 'Accept: application/xml';
    curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);

    $result = curl_exec($ch);
    if (curl_errno($ch)) {
        echo 'Error:' . curl_error($ch);
    }
    curl_close($ch);

    $xml = simplexml_load_string($result);
    if ($xml !== false) {
        foreach ($xml->Exrate as $item) {
            if ((string)$item['CurrencyCode'] === 'USD') {
                return (float)str_replace(',', '', (string)$item['Transfer']);
            }
        }
    }
    return false;
}

/**
 * @param $db
 * @return array|false|void|null
 */
function getAllPendingTransactions($db){
    $query ="select iup.payment_id, iup.payer_iuid_fk ,iup.order_key,ipp.amount, ipp.plan_amount from i_user_payments as iup
             left join i_premium_plans as ipp on ipp.plan_id=iup.credit_plan_id
             where iup.payment_status='pending';";
    $getPendingTransactions = mysqli_query($db, $query) or die(mysqli_error($db));
    return mysqli_fetch_all($getPendingTransactions, MYSQLI_ASSOC);
}

/**
 * Get all payment data
 * @param $db
 * @return array|false|void|null
 */
function getPaymentData($db)
{
    $query = 'SELECT * FROM `i_payment_methods`';
    $getPaymentData = mysqli_query($db, $query) or die(mysqli_error($db));
    return mysqli_fetch_array($getPaymentData, MYSQLI_ASSOC);
}